This implements the trivial change needed to move back from the hip{Something}_{x, y, z} macros to the natural CUDA syntax of Something.{x, y, z}. This is contained in lines 384-404 in hip_runtime.h. All of the other changes have to do with changing unit tests to use this syntax. The macros are retained for backwards compatibility.

[ROCm/hip commit: cffd0e14eb]
Этот коммит содержится в:
Alex Voicu
2017-11-19 01:54:12 +00:00
родитель 0fd5239b14
Коммит 962bf7bfda
60 изменённых файлов: 270 добавлений и 248 удалений
+1 -1
Просмотреть файл
@@ -36,7 +36,7 @@ __device__ int globalOut[NUM];
__global__ void Assign(hipLaunchParm lp, int* Out)
{
int tid = hipThreadIdx_x + hipBlockIdx_x * hipBlockDim_x;
int tid = threadIdx.x + blockIdx.x * blockDim.x;
Out[tid] = globalIn[tid];
globalOut[tid] = globalIn[tid];
}